#!/usr/bin/env python

"""Tests for `py_casim.tools."""

import pytest

from py_casim.tools import get_share, get_all_shares


@pytest.fixture
def response(datadir):
    """Read html sample from resp.html file."""
    contents = (datadir / 'resp.html').read_text()
    return contents


def test_get_share(response):
    """Simple test for get_share()."""
    url_share = get_share(response, 7)
    expected = ("https://nsa40.casimages.com/img/"
                "2020/02/17/200217113356178313.png")
    assert url_share == expected


def test_get_all_shares(response):
    """Simple test for get_all_shares()."""
    res = get_all_shares(response)
    assert len(res) == 8  # site gives 8 different image links



"""Some Beautiful soup functions."""

from bs4 import BeautifulSoup


def get_soup(html):
    """Transofm html in BeautifulSoup."""
    return BeautifulSoup(html, 'html.parser')


def _get_inputs(html):
    soup = get_soup(html)
    col = soup.select_one("div.col-sm-9")
    return [i["value"] for i in col.select("input.form-control")]


def get_share(html, index):
    """Get the share with given index.

    Args:
        html (str): input html
        index (int): index of wanted result (0 to 7)

    Returns:
        str: url or code to share image
    """
    return _get_inputs(html)[index]


def get_all_shares(html):
    """Get all url/codes to share image."""
    return _get_inputs(html)
